==> com.liferay.commerce.shipment.web-4.0.55-sources.jar: com/liferay/commerce/shipment/web/internal/frontend/data/set/view/table/CommerceShippableOrderItemsTableFDSView.java <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.commerce.shipment.web.internal.frontend.data.set.view.table;

import com.liferay.commerce.constants.CommerceShipmentFDSNames;
import com.liferay.frontend.data.set.view.FDSView;
import com.liferay.frontend.data.set.view.table.BaseTableFDSView;
import com.liferay.frontend.data.set.view.table.FDSTableSchema;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilder;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilderFactory;

import java.util.Locale;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Alec Sloan
 */
@Component(
	property = "frontend.data.set.name=" + CommerceShipmentFDSNames.SHIPPABLE_ORDER_ITEMS,
	service = FDSView.class
)
public class CommerceShippableOrderItemsTableFDSView extends BaseTableFDSView {

	@Override
	public FDSTableSchema getFDSTableSchema(Locale locale) {
		FDSTableSchemaBuilder fdsTableSchemaBuilder =
			_fdsTableSchemaBuilderFactory.create();

		return fdsTableSchemaBuilder.add(
			"sku", "sku"
		).add(
			"orderId", "order-id"
		).add(
			"quantity", "outstanding-quantity"
		).add(
			"available", "available"
		).add(
			"icon", "address-matches-shipment"
		).add(
			"shippingMethodAndOptionName", "shipping-method-and-option"
		).build();
	}

	@Reference
	private FDSTableSchemaBuilderFactory _fdsTableSchemaBuilderFactory;

}

==> com.liferay.commerce.shipment.web-4.0.60-sources.jar: com/liferay/commerce/shipment/web/internal/frontend/data/set/view/table/CommerceShippableOrderItemsTableFDSView.java <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.commerce.shipment.web.internal.frontend.data.set.view.table;

import com.liferay.commerce.constants.CommerceShipmentFDSNames;
import com.liferay.frontend.data.set.view.FDSView;
import com.liferay.frontend.data.set.view.table.BaseTableFDSView;
import com.liferay.frontend.data.set.view.table.FDSTableSchema;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilder;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilderFactory;
import com.liferay.portal.kernel.feature.flag.FeatureFlagManagerUtil;

import java.util.Locale;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Alec Sloan
 */
@Component(
	property = "frontend.data.set.name=" + CommerceShipmentFDSNames.SHIPPABLE_ORDER_ITEMS,
	service = FDSView.class
)
public class CommerceShippableOrderItemsTableFDSView extends BaseTableFDSView {

	@Override
	public FDSTableSchema getFDSTableSchema(Locale locale) {
		FDSTableSchemaBuilder fdsTableSchemaBuilder =
			_fdsTableSchemaBuilderFactory.create();

		fdsTableSchemaBuilder.add(
			"sku", "sku"
		).add(
			"orderId", "order-id"
		).add(
			"quantity", "outstanding-quantity"
		);

		if (FeatureFlagManagerUtil.isEnabled("COMMERCE-11287")) {
			fdsTableSchemaBuilder.add("unitOfMeasureKey", "uom");
		}

		return fdsTableSchemaBuilder.add(
			"available", "available"
		).add(
			"icon", "address-matches-shipment"
		).add(
			"shippingMethodAndOptionName", "shipping-method-and-option"
		).build();
	}

	@Reference
	private FDSTableSchemaBuilderFactory _fdsTableSchemaBuilderFactory;

}
